#
# spec file for package cloudflared
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cloudflared
Version:        2024.9.1
Release:        1.1
Summary:        Cloudflare Tunnel client
License:        Apache-2.0
Group:          Productivity/Networking/System
URL:            https://github.com/cloudflare/cloudflared
Source0:        https://github.com/cloudflare/cloudflared/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
# PATCH-FIX-OPENSUSE 001-skip-test.patch hillwood@opensuse.org
Patch0:         001-skip-test.patch
# PATCH-FIX-OPENSUSE 002-use-pie.patch hillwood@opensuse.org
Patch1:         002-use-pie.patch
Patch2:         reproducible.patch
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.22
AutoReqProv:    Off
%{go_provides}

%description
Contains the command-line client for Cloudflare Tunnel, a tunneling daemon that
proxies traffic from the Cloudflare network to your origins. This daemon sits
between Cloudflare network and your origin (e.g. a webserver). Cloudflare
attracts client requests and sends them to you via this daemon, without
requiring you to poke holes on your firewall --- your origin can remain as
closed as possible. Extensive documentation can be found in the Cloudflare
Tunnel section of the Cloudflare Docs. All usages related with proxying to your
origins are available under cloudflared tunnel help.

%prep
%autosetup -p1 -a1 -n %{name}-%{version}

%build
%make_build GOARCH=$(go env GOARCH)

%install
%make_install GOARCH=$(go env GOARCH)

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Fri Sep 13 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2024.9.1
  * TUN-8546: Fix final artifacts paths
  * TUN-8583: change final directory of artifacts
  * TUN-8585: Avoid creating GH client when dry-run is true
  * TUN-8591 login command without extra text
  * TUN-8592: Use metadata from the edge to determine if request body is
    empty for QUIC transport
  * TUN-8484: Print response when QuickTunnel can't be unmarshalled
  * TUN-8621: Prevent QUIC connection from closing before grace period after
    unregistering
  * PPIP-2310: Update quick tunnel disclaimer
* Mon Aug  5 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2024.7.3
  * TUN-8546: Fix final artifacts paths
* Tue Jul 30 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2024.7.1
  * Add user-agent for quick-tunnel requests
  * Add default noop logger for capnprpc
  * cloudflared uses new PQ curve ID
  * use -p flag to create intermediate directories
* Wed Jul 17 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to not include the build date (boo#1047218)
* Mon Jul  8 2024 Andreas Schwab <schwab@suse.de>
- Define GOARCH
- Remove 003-support-ppc64le.patch.
* Thu Jul  4 2024 Hillwood Yang <hillwood@opensuse.org>
- Add 003-support-ppc64le.patch
* Mon Jun 17 2024 Hillwood Yang <hillwood@opensuse.org>
- Initial package for version 2024.6.0
- Add 001-skip-test.patch and 002-use-pie.patch
